@@ -153,11 +153,16 @@ class VCSFileStartHook(hook.Hook):
 
 # internals to be able to create new vcs repo revision using rql queries #######
 
+class VCSetAtRevisionOp(hook.Operation):
+
+    def precommit_event(self):
+        bridge.set_at_revision(self.session, self.revision.eid)
+
+
 class VCTransactionOp(hook.LateOperation):
 
     def precommit_event(self):
         self.transaction.precommit()
-        bridge.set_at_revision(self.session, self.revision.eid)
 
     def revertprecommit_event(self):
         self.transaction.rollback()
@@ -224,6 +229,9 @@ class AddRevisionHook(hook.Hook):
         transaction.reveid = entity.eid
         transactions[vcsrepoeid] = transaction
         entity.cw_edited['revision'] = transaction.rev
+        # VCTransactionOp is a late operation, but we shouldn't wait that much
+        # to set at_revision relation, so use two distinct operation
+        VCSetAtRevisionOp(session, revision=entity)
         VCTransactionOp(session, revision=entity, transaction=transaction)
 
 
