@@ -56,6 +56,8 @@ class Repository(EntityType):
     import_revision_content = Boolean(default=True,
                                       description=_('import contents of files touched by a revision. '
                                                     'It may cause performance issue when scaling.'))
+    has_anonymous_access = Boolean(default=True,
+                                   description=_('Tell if user needs an account to checkout the repository.'))
 
 
 class Revision(EntityType):
