@@ -130,7 +130,11 @@ class RepositoryCheckOutInstructionsView(EntityView):
         w(u'<p>%s</p>' % _('You can browse the source code by following <a href="%s">this link</a>.')
           % xml_escape(entity.source_url))
         w(u'<h3>%s</h3>' % _('Command-Line Access'))
-        w(u'<p>%s</p>' % _('Non-members may check out a read-only working copy anonymously over HTTP.'))
+        if entity.has_anonymous_access:
+            msg = _('Non-members may check out a read-only working copy anonymously over HTTP.')
+        else:
+            msg = _('Members only may check out working copy over HTTP.')
+        w(u'<p>%s</p>' % msg)
         w(u'<p>%s</p>' % _('Use this command to check out the latest project source code:'))
         w(u'<pre>')
         if entity.type == 'mercurial':
